@@ -1,12 +1,14 @@
 =pod
 
-=head1 MEME::Alphabet
+=head1 NAME
 
-Provides nucleobase alphabet capabilities for Perl code.
+MEME::Alphabet - Provides nucleobase alphabet capabilities for Perl code.
 
-=head2 Copyright and license
+=head1 AUTHORS
 
-Author: James Johnson and Timothy L. Bailey.
+James Johnson and Timothy L. Bailey.
+
+=head1 LICENSE
 
 Copyright
 (1994 - 2017) The Regents of the University of California.
@@ -20,7 +22,7 @@ the following three paragraphs appear in all copies.
 
 Those desiring to incorporate this software into commercial
 products or use for commercial purposes should contact the
-Technology Transfer Office, University of California, San Diego,*
+Technology Transfer Office, University of California, San Diego,
 9500 Gilman Drive, La Jolla, California, 92093-0910,
 Ph: (619) 534 5815.
 
@@ -52,7 +54,7 @@ use Carp;
 use Fcntl qw(O_RDONLY);
 
 # pinned to the latest MEME Suite version (x.yy.z), and then versioned from there
-use version; our $VERSION = version->declare("v4.12.0.1");
+use version; our $VERSION = version->declare("v4.12.0.1.1");
 
 require Exporter;
 our @ISA = qw(Exporter);
